@@ -96,10 +96,10 @@ KWordQuizApp::KWordQuizApp(QWidget*):KXmlGuiWindow(0)
 
   if (Prefs::firstRun())
   {
-    fileOpenRecent->addUrl(QUrl::fromLocalFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, "kwordquiz/examples/example.kvtml")));
-    fileOpenRecent->addUrl(QUrl::fromLocalFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, "kwordquiz/examples/french_verbs.kvtml")));
-    fileOpenRecent->addUrl(QUrl::fromLocalFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, "kwordquiz/examples/fill_in_the_blank.kvtml")));
-    fileOpenRecent->addUrl(QUrl::fromLocalFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, "kwordquiz/examples/us_states_and_capitals.kvtml")));
+    fileOpenRecent->addUrl(QUrl::fromLocalFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kwordquiz/examples/example.kvtml"))));
+    fileOpenRecent->addUrl(QUrl::fromLocalFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kwordquiz/examples/french_verbs.kvtml"))));
+    fileOpenRecent->addUrl(QUrl::fromLocalFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kwordquiz/examples/fill_in_the_blank.kvtml"))));
+    fileOpenRecent->addUrl(QUrl::fromLocalFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kwordquiz/examples/us_states_and_capitals.kvtml"))));
     Prefs::setFirstRun(false);
   }
 }
@@ -166,9 +166,9 @@ void KWordQuizApp::initActions()
   m_undoStack = new QUndoStack();
   editUndo = KUndoActions::createUndoAction(m_undoStack, actionCollection());
   editRedo = KUndoActions::createRedoAction(m_undoStack, actionCollection());
-  connect(m_undoStack, SIGNAL(cleanChanged(bool)), this, SLOT(slotCleanChanged(bool)));
-  connect(m_undoStack, SIGNAL(undoTextChanged(QString)), this, SLOT(slotUndoTextChanged(QString)));
-  connect(m_undoStack, SIGNAL(redoTextChanged(QString)), this, SLOT(slotRedoTextChanged(QString)));
+  connect(m_undoStack, &QUndoStack::cleanChanged, this, &KWordQuizApp::slotCleanChanged);
+  connect(m_undoStack, &QUndoStack::undoTextChanged, this, &KWordQuizApp::slotUndoTextChanged);
+  connect(m_undoStack, &QUndoStack::redoTextChanged, this, &KWordQuizApp::slotRedoTextChanged);
 
   editCut = KStandardAction::cut(this, SLOT(slotEditCut()), actionCollection());
   editCut->setWhatsThis(i18n("Cuts the text from the selected cells and places it on the clipboard"));
@@ -191,91 +191,91 @@ void KWordQuizApp::initActions()
   editClear->setToolTip(editClear->whatsThis());
   editClear->setStatusTip(editClear->whatsThis());
 
-  editInsert = actionCollection()->addAction("edit_insert");
-  editInsert->setIcon(QIcon::fromTheme("insert-table-row"));
+  editInsert = actionCollection()->addAction(QStringLiteral("edit_insert"));
+  editInsert->setIcon(QIcon::fromTheme(QStringLiteral("insert-table-row")));
   editInsert->setText(i18n("&Insert Row"));
   editInsert->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_I));
   editInsert->setWhatsThis(i18n("Inserts a new row above the current row"));
   editInsert->setToolTip(editInsert->whatsThis());
   editInsert->setStatusTip(editInsert->whatsThis());
-  connect(editInsert, SIGNAL(triggered(bool)), this, SLOT(slotEditInsert()));
+  connect(editInsert, &QAction::triggered, this, &KWordQuizApp::slotEditInsert);
 
-  editDelete = actionCollection()->addAction("edit_delete");
-  editDelete->setIcon(QIcon::fromTheme("delete-table-row"));
+  editDelete = actionCollection()->addAction(QStringLiteral("edit_delete"));
+  editDelete->setIcon(QIcon::fromTheme(QStringLiteral("delete-table-row")));
   editDelete->setText(i18n("&Delete Row"));
   editDelete->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_K));
   editDelete->setWhatsThis(i18n("Deletes the selected row(s)"));
   editDelete->setToolTip(editDelete->whatsThis());
   editDelete->setStatusTip(editDelete->whatsThis());
-  connect(editDelete, SIGNAL(triggered(bool)), this, SLOT(slotEditDelete()));
+  connect(editDelete, &QAction::triggered, this, &KWordQuizApp::slotEditDelete);
 
-  editMarkBlank = actionCollection()->addAction("edit_mark_blank");
-  editMarkBlank->setIcon(QIcon::fromTheme("markasblank"));
+  editMarkBlank = actionCollection()->addAction(QStringLiteral("edit_mark_blank"));
+  editMarkBlank->setIcon(QIcon::fromTheme(QStringLiteral("markasblank")));
   editMarkBlank->setText(i18n("&Mark as Blank"));
   editMarkBlank->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_M));
   editMarkBlank->setWhatsThis(i18n("Marks the current or selected word as a blank for Fill-in-the-blank"));
   editMarkBlank->setToolTip(editMarkBlank->whatsThis());
   editMarkBlank->setStatusTip(editMarkBlank->whatsThis());
-  connect(editMarkBlank, SIGNAL(triggered(bool)), this, SLOT(slotEditMarkBlank()));
+  connect(editMarkBlank, &QAction::triggered, this, &KWordQuizApp::slotEditMarkBlank);
 
-  editUnmarkBlank = actionCollection()->addAction("edit_unmark_blank");
-  editUnmarkBlank->setIcon(QIcon::fromTheme("unmarkasblank"));
+  editUnmarkBlank = actionCollection()->addAction(QStringLiteral("edit_unmark_blank"));
+  editUnmarkBlank->setIcon(QIcon::fromTheme(QStringLiteral("unmarkasblank")));
   editUnmarkBlank->setText(i18n("&Unmark Blanks"));
   editUnmarkBlank->setWhatsThis(i18n("Removes blanks from the current or selected word"));
   editUnmarkBlank->setToolTip(editUnmarkBlank->whatsThis());
   editUnmarkBlank->setStatusTip(editUnmarkBlank->whatsThis());
-  connect(editUnmarkBlank, SIGNAL(triggered(bool)), this, SLOT(slotEditUnmarkBlank()));
+  connect(editUnmarkBlank, &QAction::triggered, this, &KWordQuizApp::slotEditUnmarkBlank);
 
-  vocabLanguages = actionCollection()->addAction("vocab_languages");
-  vocabLanguages->setIcon(QIcon::fromTheme("languages"));
+  vocabLanguages = actionCollection()->addAction(QStringLiteral("vocab_languages"));
+  vocabLanguages->setIcon(QIcon::fromTheme(QStringLiteral("languages")));
   vocabLanguages->setText(i18n("&Column Settings..."));
   vocabLanguages->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_L));
   vocabLanguages->setWhatsThis(i18n("Defines the column settings for the active vocabulary"));
   vocabLanguages->setToolTip(vocabLanguages->whatsThis());
   vocabLanguages->setStatusTip(vocabLanguages->whatsThis());
-  connect(vocabLanguages, SIGNAL(triggered(bool)), this, SLOT(slotVocabLanguages()));
+  connect(vocabLanguages, &QAction::triggered, this, &KWordQuizApp::slotVocabLanguages);
 
-  vocabFont = actionCollection()->addAction("vocab_font");
-  vocabFont->setIcon(QIcon::fromTheme("preferences-desktop-font"));
+  vocabFont = actionCollection()->addAction(QStringLiteral("vocab_font"));
+  vocabFont->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-font")));
   vocabFont->setText(i18n("&Font..."));
   vocabFont->setWhatsThis(i18n("Defines the font used by the editor"));
   vocabFont->setToolTip(vocabFont->whatsThis());
   vocabFont->setStatusTip(vocabFont->whatsThis());
-  connect(vocabFont, SIGNAL(triggered(bool)), this, SLOT(slotVocabFont()));
+  connect(vocabFont, &QAction::triggered, this, &KWordQuizApp::slotVocabFont);
 
-  a = actionCollection()->addAction("vocab_image");
-  a->setIcon(QIcon::fromTheme("image-x-generic"));
+  a = actionCollection()->addAction(QStringLiteral("vocab_image"));
+  a->setIcon(QIcon::fromTheme(QStringLiteral("image-x-generic")));
   a->setText(i18n("Link &Image..."));
   a->setWhatsThis(i18n("Links an image with the current entry"));
   a->setToolTip(a->whatsThis());
   a->setStatusTip(a->whatsThis());
-  connect(a, SIGNAL(triggered(bool)), this, SLOT(slotVocabImage()));
+  connect(a, &QAction::triggered, this, &KWordQuizApp::slotVocabImage);
 
-  a = actionCollection()->addAction("vocab_sound");
-  a->setIcon(QIcon::fromTheme("audio-x-generic"));
+  a = actionCollection()->addAction(QStringLiteral("vocab_sound"));
+  a->setIcon(QIcon::fromTheme(QStringLiteral("audio-x-generic")));
   a->setText(i18n("Link &Sound..."));
   a->setWhatsThis(i18n("Links a sound with the current entry"));
   a->setToolTip(a->whatsThis());
   a->setStatusTip(a->whatsThis());
-  connect(a, SIGNAL(triggered(bool)), this, SLOT(slotVocabSound()));
+  connect(a, &QAction::triggered, this, &KWordQuizApp::slotVocabSound);
 
-  vocabAdjustRows = actionCollection()->addAction("vocab_adjust_rows");
+  vocabAdjustRows = actionCollection()->addAction(QStringLiteral("vocab_adjust_rows"));
   //vocabAdjustRows->setIcon(QIcon::fromTheme());
   vocabAdjustRows->setText(i18n("&Adjust Row Heights"));
   vocabAdjustRows->setWhatsThis(i18n("Automatically adjusts the height of selected rows"));
   vocabAdjustRows->setToolTip(vocabAdjustRows->whatsThis());
   vocabAdjustRows->setStatusTip(vocabAdjustRows->whatsThis());
-  connect(vocabAdjustRows, SIGNAL(triggered(bool)), this, SLOT(slotVocabAdjustRows()));
+  connect(vocabAdjustRows, &QAction::triggered, this, &KWordQuizApp::slotVocabAdjustRows);
 
-  vocabShuffle = actionCollection()->addAction("vocab_shuffle");
-  vocabShuffle->setIcon(QIcon::fromTheme("shuffle"));
+  vocabShuffle = actionCollection()->addAction(QStringLiteral("vocab_shuffle"));
+  vocabShuffle->setIcon(QIcon::fromTheme(QStringLiteral("shuffle")));
   vocabShuffle->setText(i18n("Sh&uffle"));
   vocabShuffle->setWhatsThis(i18n("Shuffles the entries of the active vocabulary"));
   vocabShuffle->setToolTip(vocabShuffle->whatsThis());
   vocabShuffle->setStatusTip(vocabShuffle->whatsThis());
-  connect(vocabShuffle, SIGNAL(triggered(bool)), this, SLOT(slotVocabShuffle()));
+  connect(vocabShuffle, &QAction::triggered, this, &KWordQuizApp::slotVocabShuffle);
 
-  vocabLayouts = actionCollection()->addAction("vocab_layouts");;
+  vocabLayouts = actionCollection()->addAction(QStringLiteral("vocab_layouts"));;
   vocabLayouts->setText(i18n("&Keyboard Layout"));
   vocabLayouts->setWhatsThis(i18n("Shows available keyboard layouts"));
   vocabLayouts->setToolTip(vocabLayouts->whatsThis());
@@ -284,25 +284,25 @@ void KWordQuizApp::initActions()
   vocabLayouts->setMenu(m);
 
   m_layoutActionGroup = new QActionGroup(this);
-  connect(m_layoutActionGroup, SIGNAL(triggered(QAction*)), this, SLOT(slotLayoutActionGroupTriggered(QAction*)));
+  connect(m_layoutActionGroup, &QActionGroup::triggered, this, &KWordQuizApp::slotLayoutActionGroupTriggered);
 
-  m_modeActionMenu = actionCollection()->add<KActionMenu>("mode_0");
-  m_modeActionMenu->setIcon(QIcon::fromTheme("mode1"));
+  m_modeActionMenu = actionCollection()->add<KActionMenu>(QStringLiteral("mode_0"));
+  m_modeActionMenu->setIcon(QIcon::fromTheme(QStringLiteral("mode1")));
   m_modeActionMenu->setText(i18n("Change Mode"));
   m_modeActionMenu->setIconText(i18n("Mode"));
   m_modeActionMenu->setWhatsThis(i18n("Changes the mode used in quiz sessions"));
   m_modeActionMenu->setToolTip(m_modeActionMenu->whatsThis());
   m_modeActionMenu->setStatusTip(m_modeActionMenu->whatsThis());
-  connect(m_modeActionMenu, SIGNAL(triggered(bool)), this, SLOT(slotModeChange()));
+  connect(m_modeActionMenu, &QAction::triggered, this, &KWordQuizApp::slotModeChange);
 
   m_modeActionGroup = new QActionGroup(this);
-  connect(m_modeActionGroup, SIGNAL(triggered(QAction*)), this, SLOT(slotModeActionGroupTriggered(QAction*)));
+  connect(m_modeActionGroup, &QActionGroup::triggered, this, &KWordQuizApp::slotModeActionGroupTriggered);
 
   for (int i = 1; i <=5; ++i) {
-    a = actionCollection()->addAction(QString("mode_%1").arg(QString::number(i)));
+    a = actionCollection()->addAction(QStringLiteral("mode_%1").arg(QString::number(i)));
     a->setData(i);
     a->setCheckable(true);
-    a->setIcon(QIcon::fromTheme(QString("mode%1").arg(QString::number(i))));
+    a->setIcon(QIcon::fromTheme(QStringLiteral("mode%1").arg(QString::number(i))));
     a->setWhatsThis(i18n("Selects this mode"));
     a->setToolTip(a->whatsThis());
     a->setStatusTip(a->whatsThis());
@@ -310,130 +310,130 @@ void KWordQuizApp::initActions()
     m_modeActionGroup->addAction(a);
   }
 
-  quizEditor = actionCollection()->addAction("quiz_editor");
-  quizEditor->setIcon(QIcon::fromTheme("editor"));
+  quizEditor = actionCollection()->addAction(QStringLiteral("quiz_editor"));
+  quizEditor->setIcon(QIcon::fromTheme(QStringLiteral("editor")));
   quizEditor->setText(i18nc("@item:inlistbox activate vocabulary editor", "&Editor"));
   quizEditor->setShortcut(QKeySequence(Qt::Key_F6));
   quizEditor->setWhatsThis(i18n("Activates the vocabulary editor"));
   quizEditor->setToolTip(quizEditor->whatsThis());
   quizEditor->setStatusTip(quizEditor->whatsThis());
-  connect(quizEditor, SIGNAL(triggered(bool)), this, SLOT(slotQuizEditor()));
+  connect(quizEditor, &QAction::triggered, this, &KWordQuizApp::slotQuizEditor);
 
-  quizFlash = actionCollection()->addAction("quiz_flash");
-  quizFlash->setIcon(QIcon::fromTheme("flash"));
+  quizFlash = actionCollection()->addAction(QStringLiteral("quiz_flash"));
+  quizFlash->setIcon(QIcon::fromTheme(QStringLiteral("flash")));
   quizFlash->setText(i18n("&Flashcard"));
   quizFlash->setShortcut(QKeySequence(Qt::Key_F7));
   quizFlash->setWhatsThis(i18n("Starts a flashcard session using the active vocabulary"));
   quizFlash->setToolTip(quizFlash->whatsThis());
   quizFlash->setStatusTip(quizFlash->whatsThis());
-  connect(quizFlash, SIGNAL(triggered(bool)), this, SLOT(slotQuizFlash()));
+  connect(quizFlash, &QAction::triggered, this, &KWordQuizApp::slotQuizFlash);
 
-  quizMultiple = actionCollection()->addAction("quiz_multiple");
-  quizMultiple->setIcon(QIcon::fromTheme("multiple"));
+  quizMultiple = actionCollection()->addAction(QStringLiteral("quiz_multiple"));
+  quizMultiple->setIcon(QIcon::fromTheme(QStringLiteral("multiple")));
   quizMultiple->setText(i18n("&Multiple Choice"));
   quizMultiple->setShortcut(QKeySequence(Qt::Key_F8));
   quizMultiple->setWhatsThis(i18n("Starts a multiple choice session using the active vocabulary"));
   quizMultiple->setToolTip(quizMultiple->whatsThis());
   quizMultiple->setStatusTip(quizMultiple->whatsThis());
-  connect(quizMultiple, SIGNAL(triggered(bool)), this, SLOT(slotQuizMultiple()));
+  connect(quizMultiple, &QAction::triggered, this, &KWordQuizApp::slotQuizMultiple);
 
-  quizQA = actionCollection()->addAction("quiz_qa");
-  quizQA->setIcon(QIcon::fromTheme("qa"));
+  quizQA = actionCollection()->addAction(QStringLiteral("quiz_qa"));
+  quizQA->setIcon(QIcon::fromTheme(QStringLiteral("qa")));
   quizQA->setText(i18n("&Question and Answer"));
   quizQA->setIconText(i18n("Q&&A"));
   quizQA->setShortcut(QKeySequence(Qt::Key_F9));
   quizQA->setWhatsThis(i18n("Starts a question and answer session using the active vocabulary"));
   quizQA->setToolTip(quizQA->whatsThis());
   quizQA->setStatusTip(quizQA->whatsThis());
-  connect(quizQA, SIGNAL(triggered(bool)), this, SLOT(slotQuizQA()));
+  connect(quizQA, &QAction::triggered, this, &KWordQuizApp::slotQuizQA);
 
-  quizCheck = actionCollection()->addAction("quiz_check");
-  quizCheck->setIcon(QIcon::fromTheme("answer-correct"));
+  quizCheck = actionCollection()->addAction(QStringLiteral("quiz_check"));
+  quizCheck->setIcon(QIcon::fromTheme(QStringLiteral("answer-correct")));
   quizCheck->setText(i18n("&Check"));
   quizCheck->setShortcut(QKeySequence(Qt::Key_Return));
   quizCheck->setWhatsThis(i18n("Checks your answer to this question"));
   quizCheck->setToolTip(quizCheck->whatsThis());
   quizCheck->setStatusTip(quizCheck->whatsThis());
 
-  quizOpt1 = actionCollection()->addAction("quiz_Opt1");
+  quizOpt1 = actionCollection()->addAction(QStringLiteral("quiz_Opt1"));
   quizOpt1->setText(i18n("Choose Option &1"));
   quizOpt1->setShortcut(QKeySequence(Qt::Key_1));
 
-  quizOpt2 = actionCollection()->addAction("quiz_Opt2");
+  quizOpt2 = actionCollection()->addAction(QStringLiteral("quiz_Opt2"));
   quizOpt2->setText(i18n("Choose Option &2"));
   quizOpt2->setShortcut(QKeySequence(Qt::Key_2));
 
-  quizOpt3 = actionCollection()->addAction("quiz_Opt3");
+  quizOpt3 = actionCollection()->addAction(QStringLiteral("quiz_Opt3"));
   quizOpt3->setText(i18n("Choose Option &3"));
   quizOpt3->setShortcut(QKeySequence(Qt::Key_3));
 
-  flashKnow = actionCollection()->addAction("flash_know");
-  flashKnow->setIcon(QIcon::fromTheme("know"));
+  flashKnow = actionCollection()->addAction(QStringLiteral("flash_know"));
+  flashKnow->setIcon(QIcon::fromTheme(QStringLiteral("know")));
   flashKnow->setText(i18n("I &Know"));
   flashKnow->setShortcut(QKeySequence(Qt::Key_K));
   flashKnow->setWhatsThis(i18n("Counts this card as correct and shows the next card"));
   flashKnow->setToolTip(flashKnow->whatsThis());
   flashKnow->setStatusTip(flashKnow->whatsThis());
 
-  flashDontKnow = actionCollection()->addAction("flash_dont_know");
-  flashDontKnow->setIcon(QIcon::fromTheme("dontknow"));
+  flashDontKnow = actionCollection()->addAction(QStringLiteral("flash_dont_know"));
+  flashDontKnow->setIcon(QIcon::fromTheme(QStringLiteral("dontknow")));
   flashDontKnow->setText(i18n("I &Do Not Know"));
   flashDontKnow->setShortcut(QKeySequence(Qt::Key_D));
   flashDontKnow->setWhatsThis(i18n("Counts this card as incorrect and shows the next card"));
   flashDontKnow->setToolTip(flashDontKnow->whatsThis());
   flashDontKnow->setStatusTip(flashDontKnow->whatsThis());
 
-  qaHint = actionCollection()->addAction("qa_hint");
-  qaHint->setIcon(QIcon::fromTheme("hint"));
+  qaHint = actionCollection()->addAction(QStringLiteral("qa_hint"));
+  qaHint->setIcon(QIcon::fromTheme(QStringLiteral("hint")));
   qaHint->setText(i18n("&Hint"));
   qaHint->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_H));
   qaHint->setWhatsThis(i18n("Gets the next correct letter of the answer"));
   qaHint->setToolTip(qaHint->whatsThis());
   qaHint->setStatusTip(qaHint->whatsThis());
 
-  qaMarkLastCorrect = actionCollection()->addAction("qa_mark_last_correct");
-  qaMarkLastCorrect->setIcon(QIcon::fromTheme("answer-correct"));
+  qaMarkLastCorrect = actionCollection()->addAction(QStringLiteral("qa_mark_last_correct"));
+  qaMarkLastCorrect->setIcon(QIcon::fromTheme(QStringLiteral("answer-correct")));
   qaMarkLastCorrect->setText(i18n("Mark Last Correct"));
   qaMarkLastCorrect->setShortcut(QKeySequence(Qt::SHIFT + Qt::Key_Return));
   qaMarkLastCorrect->setWhatsThis(i18n("Marks last answer as correct"));
   qaMarkLastCorrect->setToolTip(qaMarkLastCorrect->whatsThis());
   qaMarkLastCorrect->setStatusTip(qaMarkLastCorrect->whatsThis());
 
-  quizRestart = actionCollection()->addAction("quiz_restart");
-  quizRestart->setIcon(QIcon::fromTheme("start-over"));
+  quizRestart = actionCollection()->addAction(QStringLiteral("quiz_restart"));
+  quizRestart->setIcon(QIcon::fromTheme(QStringLiteral("start-over")));
   quizRestart->setText(i18n("&Restart"));
   quizRestart->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_R));
   quizRestart->setWhatsThis(i18n("Restarts the quiz session from the beginning"));
   quizRestart->setToolTip(quizRestart->whatsThis());
   quizRestart->setStatusTip(quizRestart->whatsThis());
 
-  a = actionCollection()->addAction("quiz_audio_play");
-  a->setIcon(QIcon::fromTheme("media-playback-start"));
+  a = actionCollection()->addAction(QStringLiteral("quiz_audio_play"));
+  a->setIcon(QIcon::fromTheme(QStringLiteral("media-playback-start")));
   a->setText(i18n("&Play Audio"));
   a->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_B));
   a->setWhatsThis(i18n("Play associated audio"));
   a->setToolTip(a->whatsThis());
   a->setStatusTip(a->whatsThis());
 
-  quizRepeatErrors = actionCollection()->addAction("quiz_repeat_errors");
-  quizRepeatErrors->setIcon(QIcon::fromTheme("repeat"));
+  quizRepeatErrors = actionCollection()->addAction(QStringLiteral("quiz_repeat_errors"));
+  quizRepeatErrors->setIcon(QIcon::fromTheme(QStringLiteral("repeat")));
   quizRepeatErrors->setText(i18n("Repeat &Errors"));
   quizRepeatErrors->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_E));
   quizRepeatErrors->setWhatsThis(i18n("Repeats all incorrectly answered questions"));
   quizRepeatErrors->setToolTip(quizRepeatErrors->whatsThis());
   quizRepeatErrors->setStatusTip(quizRepeatErrors->whatsThis());
 
-  quizExportErrors = actionCollection()->addAction("quiz_export_errors");
+  quizExportErrors = actionCollection()->addAction(QStringLiteral("quiz_export_errors"));
   quizExportErrors->setIcon(KStandardGuiItem::saveAs().icon());
   quizExportErrors->setText(i18n("Export Errors &As..."));
   quizExportErrors->setWhatsThis(i18n("Exports all errors as a new vocabulary document"));
   quizExportErrors->setToolTip(quizExportErrors->whatsThis());
   quizExportErrors->setStatusTip(quizExportErrors->whatsThis());
-  connect(quizExportErrors, SIGNAL(triggered(bool)), this, SLOT(slotCreateErrorListDocument()));
+  connect(quizExportErrors, &QAction::triggered, this, &KWordQuizApp::slotCreateErrorListDocument);
 
-  configShowSearchBar = actionCollection()->add<KToggleAction>("config_show_search");
+  configShowSearchBar = actionCollection()->add<KToggleAction>(QStringLiteral("config_show_search"));
   configShowSearchBar->setText(i18n("Show Se&arch"));
-  connect(configShowSearchBar, SIGNAL(triggered(bool)), this, SLOT(slotConfigShowSearch()));
+  connect(configShowSearchBar, &QAction::triggered, this, &KWordQuizApp::slotConfigShowSearch);
   configShowSearchBar->setWhatsThis(i18n("Toggle display of the search bar"));
   configShowSearchBar->setToolTip(configShowSearchBar->whatsThis());
   configShowSearchBar->setStatusTip(configShowSearchBar->whatsThis());
@@ -452,9 +452,9 @@ void KWordQuizApp::initActions()
   connect(charMapper, SIGNAL(mapped(int)), this, SLOT(slotInsertChar(int)));
 
   for (int i = 1; i <=9; ++i) {
-    a = actionCollection()->addAction(QString("char_%1").arg(QString::number(i)));
+    a = actionCollection()->addAction(QStringLiteral("char_%1").arg(QString::number(i)));
     a->setText(i18n("Special Character <numid>%1</numid>", i));
-    a->setShortcut(QKeySequence(QString("Ctrl+%1").arg(QString::number(i))));
+    a->setShortcut(QKeySequence(QStringLiteral("Ctrl+%1").arg(QString::number(i))));
     connect(a, SIGNAL(triggered(bool)), charMapper, SLOT(map()));
     charMapper->setMapping(a, i);
   }
@@ -466,7 +466,7 @@ void KWordQuizApp::initActions()
   setupGUI(ToolBar | Keys | StatusBar | Create);
   setAutoSaveSettings();
 
-  configToolbar = actionCollection()->action("options_configure_toolbars");
+  configToolbar = actionCollection()->action(QStringLiteral("options_configure_toolbars"));
   configToolbar->setWhatsThis(i18n("Toggles display of the toolbars"));
   configToolbar->setToolTip(configToolbar->whatsThis());
   configToolbar->setStatusTip(configToolbar->whatsThis());
@@ -482,7 +482,7 @@ void KWordQuizApp::initStatusBar()
 void KWordQuizApp::initDocument()
 {
   m_doc = new KEduVocDocument(this);
-  m_doc->setGenerator(QString("kwordquiz %1").arg(KWQ_VERSION));
+  m_doc->setGenerator(QStringLiteral("kwordquiz %1").arg(KWQ_VERSION));
   ///@todo New kvtml documents have a locale setting which should contain the language they are written in.
   /* it would be nice to support that somehow. get hot new stuff for KHangman and KAnagram already uses this. */
   m_doc->appendIdentifier();
@@ -533,8 +533,8 @@ void KWordQuizApp::initView()
   setWindowTitle(m_doc->url().fileName() + "[*]");
   setWindowModified(false);
   m_tableView->setContextMenuPolicy(Qt::CustomContextMenu);
-  connect(m_tableView, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(slotTableContextMenuRequested(QPoint)));
-  connect(m_tableModel, SIGNAL(modelReset()), m_tableView, SLOT(slotModelReset()));
+  connect(m_tableView, &QWidget::customContextMenuRequested, this, &KWordQuizApp::slotTableContextMenuRequested);
+  connect(m_tableModel, &QAbstractItemModel::modelReset, m_tableView, &KWQTableView::slotModelReset);
 
   m_searchLine->setVisible(Prefs::showSearch());
   configShowSearchBar->setChecked(Prefs::showSearch());
@@ -545,21 +545,21 @@ void KWordQuizApp::initView()
   m_qaView = new QAView(this, actionCollection());
 
   m_editorPage = m_pageWidget->addPage(m_editorView, i18nc("@item:inlistbox vocabulary editor", "Editor"));
-  m_editorPage->setIcon(QIcon::fromTheme("editor"));
-  m_editorPage->setHeader("");
+  m_editorPage->setIcon(QIcon::fromTheme(QStringLiteral("editor")));
+  m_editorPage->setHeader(QLatin1String(""));
   m_editorPage->widget()->setLayout(editorLayout);
 
   m_flashPage = m_pageWidget->addPage(m_flashView, i18n("Flashcard"));
-  m_flashPage->setIcon(QIcon::fromTheme("flash"));
-  m_flashPage->setHeader("");
+  m_flashPage->setIcon(QIcon::fromTheme(QStringLiteral("flash")));
+  m_flashPage->setHeader(QLatin1String(""));
 
   m_multiplePage = m_pageWidget->addPage(m_multipleView, i18n("Multiple Choice"));
-  m_multiplePage->setIcon(QIcon::fromTheme("multiple"));
-  m_multiplePage->setHeader("");
+  m_multiplePage->setIcon(QIcon::fromTheme(QStringLiteral("multiple")));
+  m_multiplePage->setHeader(QLatin1String(""));
 
   m_qaPage = m_pageWidget->addPage(m_qaView, i18n("Question & Answer"));
-  m_qaPage->setIcon(QIcon::fromTheme("qa"));
-  m_qaPage->setHeader("");
+  m_qaPage->setIcon(QIcon::fromTheme(QStringLiteral("qa")));
+  m_qaPage->setHeader(QLatin1String(""));
 
   m_pageWidget->addAction(quizEditor);
   m_pageWidget->addAction(quizFlash);
@@ -831,7 +831,7 @@ void KWordQuizApp::slotFileOpenRecent(const QUrl &url)
 
 void KWordQuizApp::slotFileGHNS()
 {
-  QPointer<KNS3::DownloadDialog> getHotNewStuffDialog = new KNS3::DownloadDialog("kwordquiz.knsrc", this);
+  QPointer<KNS3::DownloadDialog> getHotNewStuffDialog = new KNS3::DownloadDialog(QStringLiteral("kwordquiz.knsrc"), this);
   getHotNewStuffDialog->exec();
   KNS3::Entry::List entries = getHotNewStuffDialog->changedEntries();
   QMimeDatabase db;
@@ -841,8 +841,8 @@ void KWordQuizApp::slotFileGHNS()
     // check mime type and if kvtml, open it
     foreach(const QString &file, entry.installedFiles()) {
       QMimeType mimeType = db.mimeTypeForFile(file);
-      if (mimeType.name() == "application/x-kvtml") {
-	    KProcess::startDetached("kwordquiz", QStringList() << file);
+      if (mimeType.name() == QLatin1String("application/x-kvtml")) {
+	    KProcess::startDetached(QStringLiteral("kwordquiz"), QStringList() << file);
       }
     }
   }
@@ -901,15 +901,15 @@ bool KWordQuizApp::saveDocAsFileName(KEduVocDocument *document)
       QString chosenFilter = fd->selectedNameFilter();
       if (!url.fileName().contains('.')) {
         qDebug() << "Selected name filter is " << chosenFilter;
-        if (chosenFilter == "*.csv")
+        if (chosenFilter == QLatin1String("*.csv"))
           url = QUrl(url.path().append(".csv"));
-        else if (chosenFilter == "*.kvtml")
+        else if (chosenFilter == QLatin1String("*.kvtml"))
           url = QUrl(url.path().append(".kvtml"));
-        else if (chosenFilter == "*.html")
+        else if (chosenFilter == QLatin1String("*.html"))
           url = QUrl(url.path().append(".html"));
       }
 
-      if (chosenFilter == "*.html") {
+      if (chosenFilter == QLatin1String("*.html")) {
         if (m_tableView->doHtmlExport(url))
           result = KEduVocDocument::NoError;
         else
@@ -1067,7 +1067,7 @@ void KWordQuizApp::slotVocabFont()
 {
   slotStatusMsg(i18n("Setting the font of the vocabulary..."));
   QFontDialog* dlg = new QFontDialog(this);
-  dlg->setObjectName("dlg_font");
+  dlg->setObjectName(QStringLiteral("dlg_font"));
   dlg->setFont(Prefs::editorFont());
   if (dlg->exec() == QDialog::Accepted)
   {
@@ -1116,9 +1116,9 @@ void KWordQuizApp::slotModeChange()
   QString newMode;
   slotStatusMsg(i18n("Updating mode..."));
   if (Prefs::mode() < 5)
-    newMode = QString("mode_%1").arg(QString::number(Prefs::mode() + 1));
+    newMode = QStringLiteral("mode_%1").arg(QString::number(Prefs::mode() + 1));
   else
-    newMode = QString("mode_1");
+    newMode = QStringLiteral("mode_1");
 
   QAction *a = actionCollection()->action(newMode);
   a->activate(QAction::Trigger);
@@ -1163,7 +1163,7 @@ void KWordQuizApp::slotCurrentPageChanged(KPageWidgetItem *current, KPageWidgetI
   disconnect(flashKnow, 0, 0, 0);
   disconnect(flashDontKnow, 0, 0, 0);
   disconnect(quizRestart, 0, 0, 0);
-  disconnect(actionCollection()->action("quiz_audio_play"), 0, 0, 0);
+  disconnect(actionCollection()->action(QStringLiteral("quiz_audio_play")), 0, 0, 0);
   disconnect(quizRepeatErrors, 0, 0, 0);
   disconnect(qaHint, 0, 0, 0);
   disconnect(qaMarkLastCorrect, 0, 0, 0);
@@ -1180,17 +1180,17 @@ void KWordQuizApp::slotCurrentPageChanged(KPageWidgetItem *current, KPageWidgetI
     }
     m_quiz = new KWQQuizModel(this);
     m_quiz->setFilterModel(m_sortFilterModel);
-    connect(m_quiz, SIGNAL(checkingAnswer(int)), m_tableView, SLOT(slotCheckedAnswer(int)));
+    connect(m_quiz, &KWQQuizModel::checkingAnswer, m_tableView, &KWQTableView::slotCheckedAnswer);
     m_quiz->setQuizType(Prefs::EnumStartSession::Flashcard);
     m_quiz->setQuizMode(Prefs::mode());
     if (m_quiz->init())
     {
       connect(quizCheck, SIGNAL(triggered(bool)), m_flashView, SLOT(slotCheck()));
-      connect(flashKnow, SIGNAL(triggered(bool)), m_flashView, SLOT(slotKnow()));
-      connect(flashDontKnow, SIGNAL(triggered(bool)), m_flashView, SLOT(slotDontKnow()));
-      connect(actionCollection()->action("quiz_audio_play"), SIGNAL(triggered(bool)), m_flashView, SLOT(slotAudioPlay()));
-      connect(quizRestart, SIGNAL(triggered(bool)), m_flashView, SLOT(slotRestart()));
-      connect(quizRepeatErrors, SIGNAL(triggered(bool)), m_flashView, SLOT(slotRepeat()));
+      connect(flashKnow, &QAction::triggered, m_flashView, &FlashView::slotKnow);
+      connect(flashDontKnow, &QAction::triggered, m_flashView, &FlashView::slotDontKnow);
+      connect(actionCollection()->action(QStringLiteral("quiz_audio_play")), &QAction::triggered, m_flashView, &KWQQuizView::slotAudioPlay);
+      connect(quizRestart, &QAction::triggered, m_flashView, &KWQQuizView::slotRestart);
+      connect(quizRepeatErrors, &QAction::triggered, m_flashView, &KWQQuizView::slotRepeat);
       connect(this, SIGNAL(settingsChanged()), m_flashView, SLOT(slotApplySettings()));
 
       m_flashView->setQuiz(m_quiz);
@@ -1212,14 +1212,14 @@ void KWordQuizApp::slotCurrentPageChanged(KPageWidgetItem *current, KPageWidgetI
     }
     m_quiz = new KWQQuizModel(this);
     m_quiz->setFilterModel(m_sortFilterModel);
-    connect(m_quiz, SIGNAL(checkingAnswer(int)), m_tableView, SLOT(slotCheckedAnswer(int)));
+    connect(m_quiz, &KWQQuizModel::checkingAnswer, m_tableView, &KWQTableView::slotCheckedAnswer);
     m_quiz->setQuizType(Prefs::EnumStartSession::MultipleChoice);
     m_quiz->setQuizMode(Prefs::mode());
     if (m_quiz->init())
     {
       connect(quizCheck, SIGNAL(triggered(bool)), m_multipleView, SLOT(slotCheck()));
-      connect(quizRestart, SIGNAL(triggered(bool)), m_multipleView, SLOT(slotRestart()));
-      connect(quizRepeatErrors, SIGNAL(triggered(bool)), m_multipleView, SLOT(slotRepeat()));
+      connect(quizRestart, &QAction::triggered, m_multipleView, &KWQQuizView::slotRestart);
+      connect(quizRepeatErrors, &QAction::triggered, m_multipleView, &KWQQuizView::slotRepeat);
       connect(this, SIGNAL(settingsChanged()), m_multipleView, SLOT(slotApplySettings()));
 
       m_multipleView->setQuiz(m_quiz);
@@ -1241,17 +1241,17 @@ void KWordQuizApp::slotCurrentPageChanged(KPageWidgetItem *current, KPageWidgetI
     }
     m_quiz = new KWQQuizModel(this);
     m_quiz->setFilterModel(m_sortFilterModel);
-    connect(m_quiz, SIGNAL(checkingAnswer(int)), m_tableView, SLOT(slotCheckedAnswer(int)));
+    connect(m_quiz, &KWQQuizModel::checkingAnswer, m_tableView, &KWQTableView::slotCheckedAnswer);
     m_quiz->setQuizType(Prefs::EnumStartSession::QA);
     m_quiz->setQuizMode(Prefs::mode());
     if (m_quiz->init())
     {
       connect(quizCheck, SIGNAL(triggered(bool)), m_qaView, SLOT(slotCheck()));
-      connect(qaHint, SIGNAL(triggered(bool)), m_qaView, SLOT(slotHint()));
-      connect(qaMarkLastCorrect, SIGNAL(triggered(bool)), m_qaView, SLOT(slotMarkLastCorrect()));
-      connect(quizRestart, SIGNAL(triggered(bool)), m_qaView, SLOT(slotRestart()));
-      connect(actionCollection()->action("quiz_audio_play"), SIGNAL(triggered(bool)), m_qaView, SLOT(slotAudioPlay()));
-      connect(quizRepeatErrors, SIGNAL(triggered(bool)), m_qaView, SLOT(slotRepeat()));
+      connect(qaHint, &QAction::triggered, m_qaView, &QAView::slotHint);
+      connect(qaMarkLastCorrect, &QAction::triggered, m_qaView, &QAView::slotMarkLastCorrect);
+      connect(quizRestart, &QAction::triggered, m_qaView, &KWQQuizView::slotRestart);
+      connect(actionCollection()->action(QStringLiteral("quiz_audio_play")), &QAction::triggered, m_qaView, &KWQQuizView::slotAudioPlay);
+      connect(quizRepeatErrors, &QAction::triggered, m_qaView, &KWQQuizView::slotRepeat);
       connect(this, SIGNAL(settingsChanged()), m_qaView, SLOT(slotApplySettings()));
 
       m_qaView->setQuiz(m_quiz);
@@ -1278,12 +1278,12 @@ void KWordQuizApp::slotConfigureNotifications( )
 /** Configure kwordquiz */
 void KWordQuizApp::slotConfigure()
 {
-  if (KWordQuizPrefs::showDialog("settings"))
+  if (KWordQuizPrefs::showDialog(QStringLiteral("settings")))
     return;
 
   //KConfigDialog didn't find an instance of this dialog, so lets create it :
-  KWordQuizPrefs* dialog = new KWordQuizPrefs(this, "settings",  Prefs::self(), actionCollection());
-  connect(dialog, SIGNAL(settingsChanged(QString)), this, SLOT(slotApplyPreferences()));
+  KWordQuizPrefs* dialog = new KWordQuizPrefs(this, QStringLiteral("settings"),  Prefs::self(), actionCollection());
+  connect(dialog, &KConfigDialog::settingsChanged, this, &KWordQuizApp::slotApplyPreferences);
   dialog->show();
 }
 
@@ -1313,7 +1313,7 @@ QIcon KWordQuizApp::charIcon(const QChar & c)
   QRect r(4, 4, 120, 120);
 
   ///A font to draw the character with
-  QFont font("sans");
+  QFont font(QStringLiteral("sans"));
   font.setPixelSize(100);
   font.setWeight(QFont::Bold);
 
@@ -1353,7 +1353,7 @@ void KWordQuizApp::slotStatusMsg(const QString &text)
 void KWordQuizApp::slotModeActionGroupTriggered(QAction *act)
 {
   if (m_quiz != 0)
-    if (KMessageBox::warningContinueCancel(this, i18n("This will restart your quiz. Do you wish to continue?"), QString(), KStandardGuiItem::cont(), KStandardGuiItem::cancel(), "askModeQuiz")
+    if (KMessageBox::warningContinueCancel(this, i18n("This will restart your quiz. Do you wish to continue?"), QString(), KStandardGuiItem::cont(), KStandardGuiItem::cancel(), QStringLiteral("askModeQuiz"))
       != KMessageBox::Continue)
       {
         m_modeActionGroup->actions()[0]->setChecked(Prefs::mode() == 1);
@@ -1433,8 +1433,8 @@ void KWordQuizApp::updateActions()
 
   vocabLanguages->setEnabled(fEdit);
   vocabFont->setEnabled(fEdit);
-  actionCollection()->action("vocab_image")->setEnabled(fEdit);
-  actionCollection()->action("vocab_sound")->setEnabled(fEdit);
+  actionCollection()->action(QStringLiteral("vocab_image"))->setEnabled(fEdit);
+  actionCollection()->action(QStringLiteral("vocab_sound"))->setEnabled(fEdit);
   vocabAdjustRows->setEnabled(fEdit);
   vocabShuffle->setEnabled(fEdit);
 
@@ -1448,7 +1448,7 @@ void KWordQuizApp::updateActions()
 
   qaHint->setEnabled((m_pageWidget->currentPage() == m_qaPage) && fQuiz);
   qaMarkLastCorrect->setVisible((m_pageWidget->currentPage() == m_qaPage) && fQuiz);
-  actionCollection()->action("quiz_audio_play")->setEnabled(false);
+  actionCollection()->action(QStringLiteral("quiz_audio_play"))->setEnabled(false);
 
   quizOpt1->setEnabled((m_pageWidget->currentPage() == m_multiplePage) && fQuiz);
   quizOpt2->setEnabled((m_pageWidget->currentPage() == m_multiplePage) && fQuiz);
@@ -1456,8 +1456,8 @@ void KWordQuizApp::updateActions()
 
   configShowSearchBar->setEnabled(fEdit);
 
-  addToolBar(Qt::RightToolBarArea, toolBar("quizToolBar"));
-  toolBar("quizToolBar")->setHidden(fEdit);
+  addToolBar(Qt::RightToolBarArea, toolBar(QStringLiteral("quizToolBar")));
+  toolBar(QStringLiteral("quizToolBar"))->setHidden(fEdit);
 }
 
 
@@ -1520,16 +1520,16 @@ void KWordQuizApp::slotCreateErrorListDocument()
 
 void KWordQuizApp::slotTableContextMenuRequested(const QPoint & pos)
 {
-    QMenu *popup = static_cast<QMenu*>(guiFactory()->container("editor_popup",this));
+    QMenu *popup = static_cast<QMenu*>(guiFactory()->container(QStringLiteral("editor_popup"),this));
     QAction *a;
     int column = m_tableView->currentIndex().column();
-    QString currentLayout = "";
+    QString currentLayout = QLatin1String("");
     currentLayout = m_tableModel->headerData(column, Qt::Horizontal, KWQTableModel::KeyboardLayoutRole).toString();
 
     // keyboard layout
     // try to talk to kxbk - get a list of keyboard layouts
-    QDBusInterface kxbk("org.kde.keyboard", "/Layouts", "org.kde.KeyboardLayouts");
-    QDBusReply<QStringList> reply = kxbk.call("getLayoutsList");
+    QDBusInterface kxbk(QStringLiteral("org.kde.keyboard"), QStringLiteral("/Layouts"), QStringLiteral("org.kde.KeyboardLayouts"));
+    QDBusReply<QStringList> reply = kxbk.call(QStringLiteral("getLayoutsList"));
     if (reply.isValid()) {
         QStringList layouts = reply;
         //layouts.prepend(QString());
